=======
Credits
=======

Development Lead
----------------

* Leonardo Giordani <giordani.leonardo@gmail.com>

Contributors
------------

* Michele D'Amico <https://github.com/la10736> (Mercurial support)
* Joris Beckers <https://github.com/jobec> (Windows installation)
